@@ -32,8 +32,11 @@ from .literals import (
     OperatorType,
     PrefixFormatType,
     PrefixTypeType,
+    PrivateConnectionProvisioningFailureCauseType,
+    PrivateConnectionProvisioningStatusType,
     S3ConnectorOperatorType,
     SalesforceConnectorOperatorType,
+    SAPODataConnectorOperatorType,
     ScheduleFrequencyTypeType,
     ServiceNowConnectorOperatorType,
     SingularConnectorOperatorType,
@@ -60,6 +63,7 @@ __all__ = (
     "AggregationConfigTypeDef",
     "AmplitudeConnectorProfileCredentialsTypeDef",
     "AmplitudeSourcePropertiesTypeDef",
+    "BasicAuthCredentialsTypeDef",
     "ConnectorConfigurationTypeDef",
     "ConnectorEntityFieldTypeDef",
     "ConnectorEntityTypeDef",
@@ -123,7 +127,10 @@ __all__ = (
     "MarketoConnectorProfileCredentialsTypeDef",
     "MarketoConnectorProfilePropertiesTypeDef",
     "MarketoSourcePropertiesTypeDef",
+    "OAuthCredentialsTypeDef",
+    "OAuthPropertiesTypeDef",
     "PrefixConfigTypeDef",
+    "PrivateConnectionProvisioningStateTypeDef",
     "RedshiftConnectorProfileCredentialsTypeDef",
     "RedshiftConnectorProfilePropertiesTypeDef",
     "RedshiftDestinationPropertiesTypeDef",
@@ -131,6 +138,9 @@ __all__ = (
     "S3DestinationPropertiesTypeDef",
     "S3OutputFormatConfigTypeDef",
     "S3SourcePropertiesTypeDef",
+    "SAPODataConnectorProfileCredentialsTypeDef",
+    "SAPODataConnectorProfilePropertiesTypeDef",
+    "SAPODataSourcePropertiesTypeDef",
     "SalesforceConnectorProfileCredentialsTypeDef",
     "SalesforceConnectorProfilePropertiesTypeDef",
     "SalesforceDestinationPropertiesTypeDef",
@@ -204,6 +214,14 @@ AmplitudeSourcePropertiesTypeDef = TypedDict(
     },
 )
 
+BasicAuthCredentialsTypeDef = TypedDict(
+    "BasicAuthCredentialsTypeDef",
+    {
+        "username": str,
+        "password": str,
+    },
+)
+
 ConnectorConfigurationTypeDef = TypedDict(
     "ConnectorConfigurationTypeDef",
     {
@@ -287,6 +305,7 @@ ConnectorMetadataTypeDef = TypedDict(
         "Upsolver": Dict[str, Any],
         "CustomerProfiles": Dict[str, Any],
         "Honeycode": "HoneycodeMetadataTypeDef",
+        "SAPOData": Dict[str, Any],
     },
     total=False,
 )
@@ -317,6 +336,7 @@ ConnectorOperatorTypeDef = TypedDict(
         "Trendmicro": TrendmicroConnectorOperatorType,
         "Veeva": VeevaConnectorOperatorType,
         "Zendesk": ZendeskConnectorOperatorType,
+        "SAPOData": SAPODataConnectorOperatorType,
     },
     total=False,
 )
@@ -348,6 +368,7 @@ ConnectorProfileCredentialsTypeDef = TypedDict(
         "Trendmicro": "TrendmicroConnectorProfileCredentialsTypeDef",
         "Veeva": "VeevaConnectorProfileCredentialsTypeDef",
         "Zendesk": "ZendeskConnectorProfileCredentialsTypeDef",
+        "SAPOData": "SAPODataConnectorProfileCredentialsTypeDef",
     },
     total=False,
 )
@@ -371,6 +392,7 @@ ConnectorProfilePropertiesTypeDef = TypedDict(
         "Trendmicro": Dict[str, Any],
         "Veeva": "VeevaConnectorProfilePropertiesTypeDef",
         "Zendesk": "ZendeskConnectorProfilePropertiesTypeDef",
+        "SAPOData": "SAPODataConnectorProfilePropertiesTypeDef",
     },
     total=False,
 )
@@ -386,6 +408,7 @@ ConnectorProfileTypeDef = TypedDict(
         "connectorProfileProperties": "ConnectorProfilePropertiesTypeDef",
         "createdAt": datetime,
         "lastUpdatedAt": datetime,
+        "privateConnectionProvisioningState": "PrivateConnectionProvisioningStateTypeDef",
     },
     total=False,
 )
@@ -1065,6 +1088,37 @@ MarketoSourcePropertiesTypeDef = TypedDict(
     },
 )
 
+_RequiredOAuthCredentialsTypeDef = TypedDict(
+    "_RequiredOAuthCredentialsTypeDef",
+    {
+        "clientId": str,
+        "clientSecret": str,
+    },
+)
+_OptionalOAuthCredentialsTypeDef = TypedDict(
+    "_OptionalOAuthCredentialsTypeDef",
+    {
+        "accessToken": str,
+        "refreshToken": str,
+        "oAuthRequest": "ConnectorOAuthRequestTypeDef",
+    },
+    total=False,
+)
+
+
+class OAuthCredentialsTypeDef(_RequiredOAuthCredentialsTypeDef, _OptionalOAuthCredentialsTypeDef):
+    pass
+
+
+OAuthPropertiesTypeDef = TypedDict(
+    "OAuthPropertiesTypeDef",
+    {
+        "tokenUrl": str,
+        "authCodeUrl": str,
+        "oAuthScopes": List[str],
+    },
+)
+
 PrefixConfigTypeDef = TypedDict(
     "PrefixConfigTypeDef",
     {
@@ -1074,6 +1128,16 @@ PrefixConfigTypeDef = TypedDict(
     total=False,
 )
 
+PrivateConnectionProvisioningStateTypeDef = TypedDict(
+    "PrivateConnectionProvisioningStateTypeDef",
+    {
+        "status": PrivateConnectionProvisioningStatusType,
+        "failureMessage": str,
+        "failureCause": PrivateConnectionProvisioningFailureCauseType,
+    },
+    total=False,
+)
+
 RedshiftConnectorProfileCredentialsTypeDef = TypedDict(
     "RedshiftConnectorProfileCredentialsTypeDef",
     {
@@ -1193,6 +1257,50 @@ class S3SourcePropertiesTypeDef(
     pass
 
 
+SAPODataConnectorProfileCredentialsTypeDef = TypedDict(
+    "SAPODataConnectorProfileCredentialsTypeDef",
+    {
+        "basicAuthCredentials": "BasicAuthCredentialsTypeDef",
+        "oAuthCredentials": "OAuthCredentialsTypeDef",
+    },
+    total=False,
+)
+
+_RequiredSAPODataConnectorProfilePropertiesTypeDef = TypedDict(
+    "_RequiredSAPODataConnectorProfilePropertiesTypeDef",
+    {
+        "applicationHostUrl": str,
+        "applicationServicePath": str,
+        "portNumber": int,
+        "clientNumber": str,
+    },
+)
+_OptionalSAPODataConnectorProfilePropertiesTypeDef = TypedDict(
+    "_OptionalSAPODataConnectorProfilePropertiesTypeDef",
+    {
+        "logonLanguage": str,
+        "privateLinkServiceName": str,
+        "oAuthProperties": "OAuthPropertiesTypeDef",
+    },
+    total=False,
+)
+
+
+class SAPODataConnectorProfilePropertiesTypeDef(
+    _RequiredSAPODataConnectorProfilePropertiesTypeDef,
+    _OptionalSAPODataConnectorProfilePropertiesTypeDef,
+):
+    pass
+
+
+SAPODataSourcePropertiesTypeDef = TypedDict(
+    "SAPODataSourcePropertiesTypeDef",
+    {
+        "objectPath": str,
+    },
+    total=False,
+)
+
 SalesforceConnectorProfileCredentialsTypeDef = TypedDict(
     "SalesforceConnectorProfileCredentialsTypeDef",
     {
@@ -1457,6 +1565,7 @@ SourceConnectorPropertiesTypeDef = TypedDict(
         "Trendmicro": "TrendmicroSourcePropertiesTypeDef",
         "Veeva": "VeevaSourcePropertiesTypeDef",
         "Zendesk": "ZendeskSourcePropertiesTypeDef",
+        "SAPOData": "SAPODataSourcePropertiesTypeDef",
     },
     total=False,
 )
@@ -1632,6 +1741,7 @@ _RequiredUpdateFlowRequestRequestTypeDef = TypedDict(
     {
         "flowName": str,
         "triggerConfig": "TriggerConfigTypeDef",
+        "sourceFlowConfig": "SourceFlowConfigTypeDef",
         "destinationFlowConfigList": List["DestinationFlowConfigTypeDef"],
         "tasks": List["TaskTypeDef"],
     },
@@ -1640,7 +1750,6 @@ _OptionalUpdateFlowRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateFlowRequestRequestTypeDef",
     {
         "description": str,
-        "sourceFlowConfig": "SourceFlowConfigTypeDef",
     },
     total=False,
 )
@@ -1719,12 +1828,29 @@ VeevaConnectorProfilePropertiesTypeDef = TypedDict(
     },
 )
 
-VeevaSourcePropertiesTypeDef = TypedDict(
-    "VeevaSourcePropertiesTypeDef",
+_RequiredVeevaSourcePropertiesTypeDef = TypedDict(
+    "_RequiredVeevaSourcePropertiesTypeDef",
     {
         "object": str,
     },
 )
+_OptionalVeevaSourcePropertiesTypeDef = TypedDict(
+    "_OptionalVeevaSourcePropertiesTypeDef",
+    {
+        "documentType": str,
+        "includeSourceFiles": bool,
+        "includeRenditions": bool,
+        "includeAllVersions": bool,
+    },
+    total=False,
+)
+
+
+class VeevaSourcePropertiesTypeDef(
+    _RequiredVeevaSourcePropertiesTypeDef, _OptionalVeevaSourcePropertiesTypeDef
+):
+    pass
+
 
 _RequiredZendeskConnectorProfileCredentialsTypeDef = TypedDict(
     "_RequiredZendeskConnectorProfileCredentialsTypeDef",
